// Wait for the DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {
    // Smooth Scrolling
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function (e) {
            e.preventDefault();
            const target = document.querySelector(this.getAttribute('href'));
            if (target) {
                target.scrollIntoView({
                    behavior: 'smooth',
                    block: 'start'
                });
            }
        });
    });

    // Mobile Navigation
    const mobileNavButton = document.querySelector('.mobile-nav-button');
    const nav = document.querySelector('nav ul');

    if (mobileNavButton && nav) {
        mobileNavButton.addEventListener('click', () => {
            nav.classList.toggle('active');
            mobileNavButton.classList.toggle('active');
        });
    }

    // Header Scroll Effect
    window.addEventListener('scroll', () => {
        const header = document.querySelector('header');
        if (window.scrollY > 50) {
            header.classList.add('scrolled');
        } else {
            header.classList.remove('scrolled');
        }
    });

    // Guest Information Form Handling
    const form = document.getElementById('rsvpForm');
    if (!form) return;

    const submitBtn = form.querySelector('.submit-btn');
    const formFields = form.querySelectorAll('.form-field');
    const plusOneSection = document.getElementById('plusOneSection');
    const hasPlusOneCheckbox = document.getElementById('hasPlusOne');

    // Handle Plus One Toggle
    if (hasPlusOneCheckbox && plusOneSection) {
        const plusOneInputs = plusOneSection.querySelectorAll('input');
        
        hasPlusOneCheckbox.addEventListener('change', function() {
            if (this.checked) {
                plusOneSection.style.display = 'grid';
                plusOneSection.style.maxHeight = '0';
                plusOneSection.style.opacity = '0';
                
                // Trigger reflow
                plusOneSection.offsetHeight;
                
                plusOneSection.style.maxHeight = plusOneSection.scrollHeight + 'px';
                plusOneSection.style.opacity = '1';
                
                // Make inputs required when checked
                plusOneInputs.forEach(input => {
                    input.required = true;
                });
            } else {
                plusOneSection.style.maxHeight = '0';
                plusOneSection.style.opacity = '0';
                
                // Make inputs not required when unchecked
                plusOneInputs.forEach(input => {
                    input.required = false;
                    input.value = ''; // Clear values when hiding
                });
                
                // Hide section after animation
                setTimeout(() => {
                    if (!hasPlusOneCheckbox.checked) {
                        plusOneSection.style.display = 'none';
                    }
                }, 300);
            }
        });
    }

    // Form Validation
    function validateForm() {
        let isValid = true;
        const email = form.querySelector('input[type="email"]');
        const phone = form.querySelector('input[type="tel"]');

        // Check required fields
        formFields.forEach(field => {
            const input = field.querySelector('input');
            if (input && input.required && !input.value.trim()) {
                isValid = false;
                field.classList.add('error');
            } else {
                field.classList.remove('error');
            }
        });

        // Validate email format
        if (email && email.value) {
            const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
            if (!emailRegex.test(email.value)) {
                isValid = false;
                email.parentElement.classList.add('error');
            }
        }

        // Validate phone format (if provided)
        if (phone && phone.value) {
            const phoneRegex = /^\+?[\d\s-]{10,}$/;
            if (!phoneRegex.test(phone.value)) {
                isValid = false;
                phone.parentElement.classList.add('error');
            }
        }

        return isValid;
    }

    // Form Submission
    form.addEventListener('submit', async function(e) {
        e.preventDefault();

        if (!validateForm()) {
            return;
        }

        // Disable submit button and show loading state
        submitBtn.disabled = true;
        submitBtn.innerHTML = '<span class="loading"></span> Sending...';

        try {
            const formData = new FormData(form);
            const response = await fetch('save_rsvp.php', {
                method: 'POST',
                body: formData
            });

            const result = await response.json();

            if (result.success) {
                // Show success message
                form.innerHTML = `
                    <div class="success-message">
                        <h3>Thank You!</h3>
                        <p>Your information has been received successfully.</p>
                    </div>
                `;
            } else {
                throw new Error(result.message || 'Failed to submit information');
            }
        } catch (error) {
            // Show error message
            const errorDiv = document.createElement('div');
            errorDiv.className = 'error-message';
            errorDiv.textContent = 'Sorry, there was an error submitting your information. Please try again.';
            form.insertBefore(errorDiv, submitBtn);
            
            // Reset submit button
            submitBtn.disabled = false;
            submitBtn.textContent = 'Submit Information';
        }
    });

    // Real-time validation
    formFields.forEach(field => {
        const input = field.querySelector('input');
        if (input) {
            input.addEventListener('input', function() {
                field.classList.remove('error');
                const errorMessage = field.querySelector('.error-message');
                if (errorMessage) {
                    errorMessage.remove();
                }
            });
        }
    });
}); 